% Demo : estimating isotone quantile functions 

% The simulated data are generated by fitting a cubic 
% regression to the dataset on growth curves used in the paper.  
% Then, normally distributed errors are added with a mean of zero
% and an increasing standard deviation as age increases.

% The original data can be requested from the Scientific
% Institute of Public Health -Belgium.

% Kaatje Bollaerts, september 2005

X = linspace(0,21,500)';
Xdesign = [ones(500,1),X,X.^2,X.^3];
b = [10.77;-0.37;0.41;-0.01];
Ypred = Xdesign*b;
error = 1.25 * X.* randn(500,1);
Y = Ypred + error;
Data =[X,Y];

% isotone quantile regression
Pars = [0,21.5,12,3,2];
[a1,yhat1,uhat1] = L1splines_iso(Data,Pars,0.05,X);
Pars = [0,21.5,12,3,10];
[a2,yhat2,uhat2] = L1splines_iso(Data,Pars,0.5,X);
Pars = [0,21.5,12,3,7];
[a3,yhat3,uhat3] = L1splines_iso(Data,Pars,0.95,X);

% Plot results
figure(1)
plot(X,uhat1,'r')
hold on
plot(X,uhat2,'r')
hold on
plot(X,uhat3,'r')
title('Isotone quantiles 0.05, 0.50 and 0.95.')
xlabel('X')
ylabel('Y)')
axis([0 21 0 150])
hold on
plot(Data(:,1),Data(:,2),'o', 'MarkerSize', 1.5')

